@@ -15,7 +15,7 @@ arguments = parser.parse_args()
 try:
     while True:
         result = GetServerTime(arguments.URL)
-        print('\033[H\033[J' + result)
+        print(result, end='\r')
         time.sleep(1)
 except KeyboardInterrupt:
     exit(1)
\ No newline at end of file
